from setuptools import setup, find_packages

setup(
    name='rpa-runner',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'robotframework>=6.0.0',
        'robotframework-pabot>=2.16.0'
    ],
    entry_points={
        'console_scripts': [
            'rpa-runner=rpa_runner.runner:main',
        ],
    },
    author='Minh Chien',
    description='A library and runner for executing Robot Framework tasks in parallel using JSON configuration.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/chiencse/rpa-sap-mock',
    classifiers=[
        'Framework :: Robot Framework',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
    ],
    python_requires='>=3.6',
)
